Method: Fog::Errors.missing_credentials
- Defined in:
- lib/fog/core/errors.rb
.missing_credentials ⇒ String
Returns The error message that will be raised, if credentials cannot be found.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/fog/core/errors.rb', line 22 def self.missing_credentials = <<-YML Missing Credentials To run as '#{Fog.credential}', add the following to your resource config file: #{Fog.credentials_path} An alternate file may be used by placing its path in the FOG_RC environment variable ####################################################### # Fog Credentials File # # Key-value pairs should look like: # :aws_access_key_id: 022QF06E7MXBSAMPLE :#{Fog.credential}: :aws_access_key_id: :aws_secret_access_key: :bluebox_api_key: :bluebox_customer_id: :brightbox_client_id: :brightbox_secret: :clodo_api_key: :clodo_username: :go_grid_api_key: :go_grid_shared_secret: :google_storage_access_key_id: :google_storage_secret_access_key: :hp_account_id: :hp_secret_key: :hp_tenant_id: :linode_api_key: :local_root: :bare_metal_cloud_password: :bare_metal_cloud_username: :public_key_path: :private_key_path: :openstack_api_key: :openstack_username: :openstack_auth_url: :openstack_tenant: :openstack_region: :ovirt_username: :ovirt_password: :ovirt_url: :libvirt_uri: :rackspace_api_key: :rackspace_username: :rackspace_servicenet: :rackspace_cdn_ssl: :stormondemand_username: :stormondemand_password: :terremark_username: :terremark_password: :voxel_api_key: :voxel_api_secret: :zerigo_email: :zerigo_token: :dnsimple_email: :dnsimple_password: :dnsmadeeasy_api_key: :dnsmadeeasy_secret_key: :cloudstack_host: :cloudstack_api_key: :cloudstack_secret_access_key: :vsphere_server: :vsphere_username: :vsphere_password: :libvirt_username: :libvirt_password: :libvirt_uri: :libvirt_ip_command: :ibm_username: :ibm_password: # # End of Fog Credentials File ####################################################### YML raise(Fog::Errors::LoadError.new()) end |